<template>
  <div class="header-wrapper">
    <div class="header-container">
      <div class="header-logo">
        <router-link
          to="/"
        >
          <img src="/src/assets/images/logo-white.svg" alt="logo">
        </router-link>
      </div>
      <div class="header-nav">
        <router-link
          to="/"
          @click="scrollToTop"
        >
          Home
        </router-link>
        <router-link
          :to="{name: 'Docs'}"
          @click="scrollToTop"
        >
          Docs
        </router-link>
        <router-link
          to="/users"
        >
          Users
        </router-link>
        <router-link
          :to="{name: 'Login'}"
          v-if="!isLogged"
          @click="scrollToTop"
        >
          Login
        </router-link>
        <span
          v-if="isLogged"
          @click="onClickLogout"
        >
          Logout
        </span>
      </div>
      <div class="burger" @click="toggleDropdown">
        <img src="/src/assets/images/burger-menu.svg" alt="burger menu">
      </div>
      <div class="dropdown-menu" v-if="isDropdownOpen">
        <router-link
          :to="{name: 'IntroTab'}"
          @click="toggleDropdown"
        >
          Home
        </router-link>
        <router-link
          :to="{name: 'Docs'}"
          @click="toggleDropdown"
        >
          Docs
        </router-link>
        <router-link
          :to="{name: 'Login'}"
          @click="toggleDropdown"
          v-if="!isLogged"
        >
          Login
        </router-link>
        <span
          v-if="isLogged"
          @click="onClickLogout"
        >
          Logout
        </span>
      </div>
    </div>
  </div>
</template>

<script setup>
import { ref, inject } from 'vue';
import { useRouter } from 'vue-router';

const isLogged = inject('isLogged');
const isDropdownOpen = ref(false);

const toggleDropdown = () => {
  isDropdownOpen.value = !isDropdownOpen.value;
  scrollToTop()
};

const scrollToTop = () => {
  window.scrollTo({
    top: 0,
    behavior: "smooth",
  });
};

async function onClickLogout(){
  toggleDropdown();
  if (!window.confirm('Are you sure you want to log out?')) return
  try {
    let response = await get("/api/auth/logout")
    let data = await response.json();
    if (response.ok) {
      console.log(data);
      isLogged.value = false;
      localStorage.removeItem('sid');
      localStorage.removeItem('user');
      router.push({ name: 'Login'});
    } else {
      console.error('Error:', data);
      alert('Registration failed: ' + data.message);
    }
  } catch (error) {
    console.error('There has been a problem with your fetch operation:', error);
    alert('An error occurred: ' + error.message);
  }
}
</script>

<style scoped>
  .header-wrapper{
    height: var(--header-heaight);
    border-bottom: 1px solid white;
    background-color: rgb(44, 62, 80);
    z-index: 2;
    user-select: none;
  }
  .header-container{
    height: 100%;
    max-width: 1140px;
    margin: 0 auto;
    padding: 0 16px;
    display: flex;
    justify-content: space-between;
  }
  .header-logo{
    max-width: 200px;
    display: flex;
    align-items: center;
  }
  .header-logo a img{
    width: 100%;
  }
  .header-nav{
    display: none;
  }
  .header-nav a,
  .header-nav span{
    padding: 0 12px;
    line-height: calc(var(--header-heaight) - 1px);
    font-size: 13px;
    font-weight: 500;
    color: rgba(255, 255, 245, 0.86);
    transition: color .25s;
    white-space: nowrap;
    text-decoration: none;
    cursor: pointer;
  }
  .header-nav a:hover,
  .header-nav span:hover,
  .dropdown-menu a:hover,
  .dropdown-menu span:hover{
    color: rgb(255, 110, 74);
  }
  .header-nav a.router-link-exact-active,
  .dropdown-menu a.router-link-exact-active {
    color: rgb(255, 110, 74);
  }
  .burger{
    width: 24px;
    display: flex;
    align-items: center;
    justify-content: center;
  }
  .burger img{
    width: 16px;
    height: 16px;
    cursor: pointer;
    filter: brightness(0) saturate(100%) invert(94%) sepia(26%) saturate(243%) hue-rotate(26deg) brightness(108%) contrast(113%);
  }
  .burger img:hover{
    opacity: 0.7;
  }
  .dropdown-menu {
    display: flex;
    flex-direction: column;
    position: absolute;
    top: 56px;
    right: 16px;
    background-color: rgb(44, 62, 80);
    border: 1px solid rgba(255, 255, 245, 0.86);
    padding: 8px;
    z-index: 10;
  }
  .dropdown-menu a,
  .dropdown-menu span {
    padding: 8px 12px;
    font-size: 13px;
    font-weight: 500;
    transition: color 0.25s;
    white-space: nowrap;
    text-decoration: none;
    color: rgba(255, 255, 245, 0.86);
    cursor: pointer;
  }
  @media screen and (min-width: 640px) {
    .header-nav{
      display: block;
    }
    .burger{
      display: none;
    }
    .dropdown-menu{
      display: none;
    }
  }
  @media screen and (min-width: 1156px) {  
    .header-wrapper{
      position: sticky;
      top: 0;
    }
    .header-container{
      padding: 0;
    }
  }
</style>
















<!--  -->